/**@file
 * ChmodDialog.m
 * @brief File chmod dialog box class.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/10.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import "ChmodDialog.h"
#import "MyDocument.h"
#import "ViewController.h"
#import "MyUtil.h"

@implementation ChmodDialog

/**
 * Base class retrieves sheet pointer.
 * @return sheet ID.
 */
- (id)sheet
{
	// initialize controls.
	id controller = [m_document controller];
	[m_mode setStringValue:[controller currentFileMode]];
	[MyUtil focusTo:m_mode onDialog:self];
	return [controller chmodDialog];
}

/**
 * OK button has pressed.
 */
- (void)onOk
{
	id controller = [m_document controller];
	[controller chmodFileTo:[m_mode stringValue]];
}

/**
 * Ask can ok.
 */
- (BOOL)canOk
{
	BOOL ret = YES;
	NSString *const val = [m_mode stringValue];
	if ([val length] != 3) {
		ret = NO;
	}
	if (ret != NO) {
		for (NSUInteger i = 0; i < 3; i++) {
			const unichar cc = [val characterAtIndex:i];
			if ((cc < '0') || (cc >'7')) {
				ret = NO;
				break;
			}
		}
	}
	if (ret == NO) {
		[MyUtil messageBoxInternational:@"invalid mode string"];
		[MyUtil focusTo:m_mode onDialog:self];
	}

	return ret;
}
@end
