/**@file
 * FileDisplay.h
 * @brief Displays remote file's attirbutes.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/08.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

/**
 * Displays remote file's attirbutes.
 */
@interface FileDisplay : NSObject {
@protected
	NSString *m_name;				// file name.
	NSString *m_date;				// file date. format MMM d HH:MM or MMM d YYYY
	NSString *m_owner;				// file's owner.
	NSString *m_group;				// file's group.
	NSUInteger m_size;				// file's size.
	NSUInteger m_mode;				// file's mode.
	BOOL m_isDirectory;				// file is directory.
	BOOL m_isLink;					// file is link.
	// parent sort option.
	NSString *m_parentSortKey;		// sort key.
	BOOL m_parentAscending;			// YES if ascending, NO if descending.
}
// properties.
@property (nonatomic, retain, setter = setFileName, getter = fileName) NSString *m_name;
@property (nonatomic, assign, getter = fileDate, readonly) NSString *m_date;
@property (nonatomic, assign, getter = fileOwner, readonly) NSString *m_owner;
@property (nonatomic, assign, getter = fileGroup, readonly) NSString *m_group;
//@property (nonatomic, assign, getter = fileSize, readonly) NSUInteger m_size;
@property (nonatomic, assign, setter = setFileMode,getter = fileMode) NSUInteger m_mode;
@property (nonatomic, assign, getter = isDirectory, readonly) BOOL m_isDirectory;
@property (nonatomic, assign, getter = isLink, readonly) BOOL m_isLink;
@property (nonatomic, retain, setter = setParentSortKey, getter = parentSortKey) NSString *m_parentSortKey;
@property (nonatomic, assign, setter = setParentAscending, getter = parentAscending) BOOL m_parentAscending;

// initialize.
- (id)initWithFtpResult:(NSString *)ftpResult;
// get file mode string.
- (NSString *)fileModeString;
// file name if link strip link target.
- (NSString *)fileTitle;

// get object count.
- (NSUInteger)count;
// set owner.
- (NSUInteger)setOwner:(NSString *)ftpResult;
// set group.
- (NSUInteger)setGroup:(NSString *)ftpResult;
// set file size.
- (NSUInteger)setFileSize:(NSString *)ftpResult;
// set file date.
- (NSUInteger)setFileDate:(NSString *)ftpResult;
// compare.
- (BOOL)isEqualFile:(id)object;
// copy function.
- (void)copyFrom:(FileDisplay *)fileDisplay;
// copare function.
- (NSComparisonResult)compare:(id)pair;
// date in NSUInteger.
- (NSUInteger)integerFileDate;
// file size.
- (unsigned long long)fileSize;
@end
