/**@file
 * FileDisplayController.h
 * @brief Controller class for FileDisplay.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/09.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import <Cocoa/Cocoa.h>
#import "FileDisplayCollection.h"

/**
 * Controller class for FileDisplay.
 */
@interface FileDisplayController : NSObject <NSOutlineViewDataSource> {
@private
	id m_controller;						// ViewController.
	NSString *m_currentDirectory;			// current directory.
	FileDisplayCollection* m_collection;	// collection class for root directory.
	NSString *m_processPath;				// current processing path.
	NSMutableDictionary *m_pathDictionary;	// path dictionary for directories.
}
@property (nonatomic, assign, getter = controller, readonly) id m_controller;
@property (nonatomic, retain, setter = setCurrentDirectory, getter = currentDirectory) NSString *m_currentDirectory;
@property (nonatomic, retain, setter = setProcessPath, getter = processPath) NSString *m_processPath;

// set view controller.
- (void)setController:(id)viewController;
// before add files.
- (void)invalidate;
// after add files.
- (void)updateAll;
// add display line.
- (void)addFileDisplay:(NSString *)ftpResult;
// add file display end.
- (void)addFileDisplayEnd;
// remove all objects.
- (void)removeAllObjects;
// get file view's data source.
- (FileDisplayCollection *)currentFileViewDataSource;
// expands only current directory.
- (void)expandOutlineView:(NSOutlineView *)outlineView;
// retrieve file display.
- (id)retrieveFileDisplay:(NSString *)filePath;
@end
