/**@file
 * FileDropTableView.h
 * @brief File drop table view class.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/17
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

/**
 * File drop table view class.
 */
@interface FileDropTableView : NSTableView <NSTableViewDelegate> {
@private
	BOOL m_bInDragging;						// dragging.
	IBOutlet id m_controller;				// controller object.
}

// call while dragging.
- (NSDragOperation)draggingSourceOperationMaskForLocal:(BOOL)isLocal;
// receive file list from dragging information.
- (NSArray *)fileListInDraggingInfo:(id <NSDraggingInfo>)info;
// notify enter dragging.
- (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender;
// current dragging object is droppable on this object or not.
- (BOOL)acceptableObject:(id <NSDraggingInfo>)info;
// dragging out from the field.
- (void)draggingExited:(id <NSDraggingInfo>)sender;
// set click point selected.
- (void)setClickPointSelected:(NSEvent *)theEvent row:(NSUInteger)row;
// double clicked.
- (void)mouseDoubleClicked:(NSEvent *)theEvent row:(NSUInteger)row;
// clear columns images.
- (void)clearColumnImages;
@end
