/**@file
 * MyUtil.h
 * @brief Utility function class.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/07.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import <Foundation/Foundation.h>

// countof macro.
#define COUNT_OF(valName, valType)				(sizeof(valName) / sizeof(valType))	// like a vc++ _countof
// processor for id[].
#define FOR_EACH_ID_ARRAY(arrayName, func)						\
for (NSUInteger i = 0; i < COUNT_OF(arrayName, id); i++) {		\
	if (func(arrayName[i]) == NO) {								\
		break;													\
	}															\
}
// processor for id[], stop counter also returned.
#define FOR_EACH_ID_ARRAY_WITH_CNT(arrayName, func, cnt)		\
for (NSUInteger i = 0; i < COUNT_OF(arrayName, id); i++) {		\
	if (func(arrayName[i]) == NO) {								\
		*cnt = i;												\
		break;													\
	}															\
}
// processor for id[] and pointer, stop counter also returned.
#define FOR_EACH_ID_ARRAY_VP_WITH_CNT(arrayName, func, vp, cnt)	\
for (NSUInteger i = 0; i < COUNT_OF(arrayName, id); i++) {		\
	if (func(arrayName[i], vp[i]) == NO) {						\
		*cnt = i;												\
		break;													\
	}															\
}

// date time templates.
#define TEMPLATE_DATE						@"yyyy-MM-dd"	// date.
#define TEMPLATE_TIME						@"HH:mm:ss.SSS"	// time.

// Utility class.
@interface MyUtil : NSObject {

}

// static methods.
// Message box functions.
+ (NSInteger)messageBox:(NSString *)text;
+ (NSInteger)messageBox:(NSString *)text withTitle:(NSString *)title;
// international versions.
+ (NSInteger)messageBoxInternational:(NSString *)text;
+ (NSInteger)messageBoxInternational:(NSString *)text withTitle:(NSString *)title;
+ (NSInteger)askYesNo:(NSString *)text;
+ (NSInteger)askYesNo:(NSString *)text withTitle:(NSString *)title;
// Get user document directory.
+ (NSString *)documentDirectory;
// Focus to NSTextField.
+ (void)focusTo:(NSTextField *)control onDialog:(id) dialog;
// Get template string.
+ (NSString *)templateString:(NSString *)path;
// trim string.
+ (NSString *)trim:(NSString *)str;
// create current date or time.
+ (NSString *)currentDateTime:(NSString *)fmt;
// is integer string or not.
+ (BOOL)isIntegerString:(NSString *)str;
// http, https URL validation.
+ (BOOL)isValidHttpProtocol:(NSString *)url;
// ask local file is directory or not.
+ (BOOL)isDirectory:(NSString *)path;
// format file name intarnational.
+ (NSString *)internationalFormat:(NSString *)format file:(NSString *)file;
@end
