/**@file
 * ProcessingDialog.m
 * @brief Processing dialog box class shows up while time taking tasks.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/20.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import "ProcessingDialog.h"
#import "MyDocument.h"
#import "ViewController.h"

@implementation ProcessingDialog

// properties.
@synthesize m_windowTitle;

/**
 * Base class retrieves sheet pointer.
 * @return sheet ID.
 */
- (id)sheet
{
	[self setWindowTitle:NSLocalizedString(@"start process", @"start process")];
	[m_label setStringValue:[self windowTitle]];
	//id controller = [m_document controller];
	return nil;//[controller processingDialog];
}

// show modal.
- (void)showModal
{
	m_sheet = [self sheet];
	[NSApp runModalForWindow:m_sheet];
}

/**
 * cancel button.
 * @param[in] sender sender object.
 */
- (IBAction)cancelButton:(id)sender
{
	id controller = [m_document controller];
	[controller setCancel:YES];	// cancel button pressed.
}

/**
 * update window title.
 * @param[in] windowTitle new window title.
 */
- (void)updateWindowTitle:(NSString *)windowTitle
{
	[self setWindowTitle:windowTitle];
	[self performSelectorOnMainThread:@selector(updateWindowTitleMainThread:) withObject:m_windowTitle waitUntilDone:NO];
}

/**
 * update window title by main thread.
 * @param[in] windowTitle new window title.
 */
- (void)updateWindowTitleMainThread:(id)windowTitle
{
	[m_label setStringValue:[self windowTitle]];
}

/**
 * close window.
 */
- (void)closeWindow
{
	[m_sheet close];
	[NSApp stopModal];
}

// constructor.
- (id)init
{
	self = [super init];
	if (self) {
		m_windowTitle = NSLocalizedString(@"start process", @"start process");
		[m_windowTitle retain];
	}
	return self;
}

// destructor.
- (void)dealloc
{
	[m_windowTitle release];
	[super dealloc];
}

@end
