/**@file
 * RenameDialog.m
 * @brief File rename dialog box class.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/10.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import "RenameDialog.h"
#import "MyDocument.h"
#import "ViewController.h"
#import "MyUtil.h"
#import "FileNameFormatter.h"

@implementation RenameDialog

@synthesize m_process;

/**
 * Base class retrieves sheet pointer.
 * @return sheet ID.
 */
- (id)sheet
{
	// initialize controls.
	id controller = [m_document controller];
	if (m_process == RENAME_DIALOG_RENAME) {
		// rename.
		[m_tile setStringValue:NSLocalizedString(@"ren", @"ren")];
		[m_name setStringValue:[controller currentFileName]];
	}
	else {
		// mkdir.
		[m_tile setStringValue:NSLocalizedString(@"mkdir", @"mkdir")];
		[m_name setStringValue:@""];
	}
	[MyUtil focusTo:m_name onDialog:self];
	return [controller renameDialog];
}

/**
 * OK button has pressed.
 */
- (void)onOk
{
	id controller = [m_document controller];
	if (m_process == RENAME_DIALOG_RENAME) {
		// rename.
		[controller renameFileTo:[m_name stringValue]];
	}
	else {
		// mkdir.
		[controller mkd:[m_name stringValue]];
	}
}

/**
 * Ask can ok.
 */
- (BOOL)canOk
{
	BOOL ret = YES;
	if ([[m_name stringValue] length] == 0) {
		if (m_process == RENAME_DIALOG_RENAME) {
			[MyUtil messageBoxInternational:@"specify file name"];
		}
		else {
			[MyUtil messageBoxInternational:@"specify directory name"];
		}
		[MyUtil focusTo:m_name onDialog:self];
		ret = NO;
	}
	else {
		NSString *input = [m_name stringValue];
		ret = [FileNameFormatter isValidFileName:input];	// validate file name.
		if (ret == NO) {
			[MyUtil messageBoxInternational:@"invalid path name"];
			[MyUtil focusTo:m_name onDialog:self];
		}
	}

	return ret;
}

@end
