/**@file
 * SettingDialog.m
 * @brief Connect setting dialog box class.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/07.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import "SettingDialog.h"
#import "ViewController.h"
#import "MyDocument.h"
#import "MyUtil.h"
#import "ConnectSettings.h"

@implementation SettingDialog

/**
 * Base class retrieves sheet pointer.
 * @return sheet ID.
 */
- (id)sheet
{
	// initialize controls.
	id setting = [m_document connectionSetting];
	[m_description setStringValue:[setting description]];
	[m_userId setStringValue:[setting userId]];
	[m_url setStringValue:[setting urlString]];
	[m_password setStringValue:[setting password]];
	const NSUInteger timeout = [setting timeout];
	[m_timeout setIntValue:timeout];
	[MyUtil focusTo:m_description onDialog:self];

	id controller = [m_document controller];
	return [controller settingDialog];
}

/**
 * OK button has pressed.
 */
- (void)onOk
{
	ConnectSettings *const connSetting = [[ConnectSettings alloc] init];
	[connSetting setDescription:[m_description stringValue]];
	[connSetting setUrl:[m_url stringValue]];
	[connSetting setUserId:[m_userId stringValue]];
	[connSetting setPassword:[m_password stringValue]];
	const CGFloat timeout = [m_timeout floatValue];
	[connSetting setTimeout:timeout];

	[m_document setConnectionSetting:connSetting];
}

/**
 * Ask can ok.
 */
- (BOOL)canOk
{
	if ([MyUtil isValidHttpProtocol:[m_url stringValue]] == NO) {
		// No URL data.
		[MyUtil messageBoxInternational:@"Invalid URL"];
		[MyUtil focusTo:m_url onDialog:self];
		return NO;
	}
	// user name.
	NSString *input = [MyUtil trim:[m_userId stringValue]];
	if ([input length] < 1) {
		[MyUtil messageBoxInternational:@"Input user name"];
		[MyUtil focusTo:m_url onDialog:self];
		return NO;
	}
	// password.
	input = [MyUtil trim:[m_password stringValue]];
	if ([input length] < 1) {
		[MyUtil messageBoxInternational:@"Input password"];
		[MyUtil focusTo:m_url onDialog:self];
		return NO;
	}
	return YES;
}

@end
