/**@file
 * ShsslClient.h
 * @brief Client class, Server is CGI.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/08.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

/**
 * Client class, Server is CGI.
 */
@interface ShsslClient : NSObject {
@private
	// use asynchronize communication.
	NSURLConnection *m_conn;			// URL connection.
	NSConditionLock *m_lock;			// condition lock.
	BOOL m_finish;						// finish flag.
	NSMutableData *m_data;				// Received data (do not use in main thread).
	BOOL m_result;						// YES if success, NO if failed.
	// connection values.
	NSString *m_currentDirectory;		// current directory of FTP.
	BOOL m_connect;						// connect flag.
	// other values.
	NSStringEncoding m_htmlEnc;			// HTML encoding.
	id m_controller;					// ViewController.
	NSString *m_command;				// command of ShSSLFT to CGI.
	NSMutableString *m_foundChars;		// found characters.
	BOOL m_commandResult;				// command result.
	// parameters.
	NSString *m_param0;					// parameter 0.
	NSString *m_param1;					// parameter 1.
	NSUInteger m_paramCount;			// parameter count.
	NSMutableData* m_contentReceiver;	// content receiver.
	NSData* m_contentSender;			// content sender.
}
// properties.
@property (nonatomic, retain, setter = setCurrentDirectory, getter = currentDirectory) NSString *m_currentDirectory;
@property (nonatomic, assign, setter = setConnect, getter = isConnect) BOOL m_connect;
@property (nonatomic, assign, setter = setController) id m_controller;
@property (nonatomic, retain, setter = setCommand, getter = command) NSString *m_command;
@property (nonatomic, assign, setter = setCommandResult, getter = commandResult) BOOL m_commandResult;
@property (nonatomic, retain, setter = setParam0, getter = param0) NSString *m_param0;
@property (nonatomic, retain, setter = setParam1, getter = param1) NSString *m_param1;

// connect to CGI.
- (BOOL)connect:(BOOL)connect;
// LIST command.
- (BOOL)list:(NSString *)currentDir;
// REN command.
- (BOOL)renameFileFrom:(NSString *)from to:(NSString *)to;
// chmod file.
- (BOOL)chmod:(NSString *)pathName mode:(NSString *)mode;
// remove directory.
- (BOOL)rmd:(NSString *)pathName;
// remove directory.
- (BOOL)rm:(NSString *)pathName;
// make directory.
- (BOOL)mkd:(NSString *)pathName;
// retr file.
- (BOOL)retr:(NSString *)pathName content:(NSMutableData *)content;
// stor file.
- (BOOL)stor:(NSString *)pathName content:(NSData *)content;

// send.
- (BOOL)send;

// Wait for complete.
- (BOOL)waitForComplete;
// release lock object.
- (void)releaseLock;
// reset lock.
- (void)resetLock;
// complete signal.
- (void)downloadCompleted;
// create connection.
- (NSURLConnection *)createConnection:(NSURLRequest *)request;
// wait loop of child thread.
- (void)currentRunLoop;

// thread procedure.
- (void)threadProc:(id)anArgument;
// create request.
- (NSURLRequest *)createRequest:(NSArray *)params;
// create request content.
- (NSData *)createRequestContent;
// create request content for store file.
- (NSData *)createUploadRequestContent;
// find server encode.
- (void)findEncodeString:(NSURLResponse *)response;

// reflect results.
- (void)reflectResults;
// notify to main thread connection is disconnected.
- (void)disconnectedMainThread:(id)some;
@end

// commands of ShSSL file transporter.
#define COMMAND_LIST							@"LIST"
#define COMMAND_CONN							@"CONN"
#define COMMAND_REN								@"REN"
#define COMMAND_CHMOD							@"CHMOD"
#define COMMAND_RMD								@"RMD"
#define COMMAND_RM								@"RM"
#define COMMAND_MKD								@"MKD"
#define COMMAND_RETR							@"RETR"
#define COMMAND_STOR							@"STOR"
