/**@file
 * ViewController.h
 * @brief The view controller class.
 * @author toru kageyama
 * Created by Toru Kageyama on 10/10/07.
 * Copyright 2010 Comona Co., Ltd. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

/**
 * The view controller class.
 */
@interface ViewController : NSObject {
@private
	// IBOutlet.
	IBOutlet id m_owner;							// owner MyDocument.
	IBOutlet NSWindow *m_mainWindow;				// main window.
	IBOutlet NSButton *m_connectButton;				// connect button.
	IBOutlet NSButton *m_settingButton;				// setting button.
	IBOutlet NSButton *m_cancelButton;				// cancel button.
	IBOutlet NSSplitView *m_splitView;				// split view;
	IBOutlet NSTableView *m_fileView;				// file view, the right side of the split view.
	IBOutlet NSOutlineView *m_directoryView;		// directory view, the left side of the split view.
	IBOutlet NSTextField *m_statusField;			// status bar field.
	IBOutlet NSTextField *m_progress;				// progress dislay.
	// dialogs.
	IBOutlet NSPanel *m_settingDialog;				// setting dialog.
	IBOutlet NSPanel *m_renameDialog;				// rename dialog.
	IBOutlet NSPanel *m_chmodDialog;				// chmod dialog.
	IBOutlet NSPanel *m_askSkipOverwriteDialog;		// ask skip overwrite dialog.
	IBOutlet NSPanel *m_cdDialog;					// change directory dialog.
	// dialog control class.
	IBOutlet id m_renameDialogController;			// RenameDialog.
	IBOutlet id m_chmodDialogController;			// ChmodDialog.
	IBOutlet id m_askSkipOverwriteDlgController;	// AskSkipOverwriteDialog class.
	IBOutlet id m_cdDialogController;				// change directory dialog controller class.

	// client class for CGI.
	id m_client;									// ShsslClient.
	// file display class.
	id m_fileDisplayController;						// FileDisplayController;
	// operation if path exist.
	BOOL m_ask;										// initialy YES.
	BOOL m_skip;									// initialy YES.
	NSString *m_savedCurDir;						// saved current directory.
	BOOL m_cancel;									// cancel flag.
	// progress title.
	NSString *m_progressTitle;						// progress. title.
	id m_progressThread;							// progress thread.
	id m_controlDisabler;
}
// properties.
@property (nonatomic, assign, getter = owner, readonly) id m_owner;
@property (nonatomic, assign, getter = mainWindow, readonly) NSWindow *m_mainWindow;
@property (nonatomic, assign, getter = fileDisplayController, readonly) id m_fileDisplayController;
@property (nonatomic, assign, getter = settingDialog, readonly) NSPanel *m_settingDialog;
@property (nonatomic, assign, getter = renameDialog, readonly) NSPanel *m_renameDialog;
@property (nonatomic, assign, getter = chmodDialog, readonly) NSPanel *m_chmodDialog;
@property (nonatomic, assign, getter = askSkipOverwriteDialog, readonly) NSPanel *m_askSkipOverwriteDialog;
@property (nonatomic, assign, getter = cdDialog, readonly) NSPanel *m_cdDialog;
@property (nonatomic, assign, getter = client, readonly) id m_client;
@property (nonatomic, retain, getter = savedCurDir, setter = setSavedCurDir) NSString *m_savedCurDir;
@property (nonatomic, assign, getter = isCanceled, setter = setCancel) BOOL m_cancel;
@property (retain, setter = setProgressTitle, getter = progressTitle) NSString *m_progressTitle;
@property (nonatomic, assign, getter = controlDisabler, setter = setControlDisabler) id m_controlDisabler;
@property (nonatomic, assign, getter = fileView, readonly) NSTableView *m_fileView;

// connect button.
- (IBAction)connectButton:(id)sender;
// cancel button.
- (IBAction)cancelButton:(id)sender;

// rename menu.
- (void)renameToMenu:(id)sender;
// chmod menu.
- (void)chmodToMenu:(id)sender;
// rmv menu.
- (void)removeFileMenu:(id)sender;
// mkdir menu.
- (void)makeDirectoryMenu:(id)sender;
// retr menu.
- (void)retrieveFile:(id)sender;
// retrieve file driven by sub thread.
- (void)retrieveFileSubThread;
// retr by drag and drop.
- (void)retrieveDroppedFile:(NSString *)targetDir;
// retr by drag and drop driven by sub thread.
- (void)retrieveDroppedFileSubThread:(NSString *)targetDir;
// retrieve file.
- (void)retrieveFileContents:(id)fd pathTo:(NSString *)pathTo;
// stor menu.
- (void)addFile:(id)sender;
// stor menu driven by sub thread.
- (void)addFileSubThread;
// stor menu with paste.
- (void)paste:(id)sender;
// stor menu with paste driven by sub thread.
- (void)pasteSubThread;
// stor menu with paste from finder.
- (void)pasteFromFinder:(id)sender;
// stor menu with paste from finder driven by sub thread.
- (void)pasteFromFinderSubThread;
// copy.
- (void)copy:(id)sender;
// cut.
- (void)cut:(id)sender;
// parent directory.
- (void)parentDirectory:(id)sender;
// change directory.
- (void)changeDirectory:(id)sender;
// make file name array.
- (NSArray *)makeFileNameArray;
// reload menu.
- (void)reloadMenu:(id)sender;
// save file contents.
- (BOOL)saveFileContent:(NSData *)content as:(id)fileDisplay lastDirectory:(BOOL)lastDirSave pathTo:(NSString *)pathTo;
// save file contents.
- (BOOL)saveFile:(NSString *)path content:(NSData *)content;
// save directory.
- (BOOL)saveDirectory:(id)directoryDisplay path:(NSString *)promptPath;
// create directory.
+ (BOOL)createDirectory:(NSString *)path;
// recursive save directory.
- (BOOL)recursiveSaveDirectory:(id)directoryDisplay withParent:(NSString *)parentDir;
// retr menu.
- (BOOL)retrieveFile:(id)fd withParent:(NSString *)parentDir;
// dropped from finder.
- (BOOL)droppedFromFinder:(id <NSDraggingInfo>)info fileDisplay:(id)fileDisplay;
// dropped from finder driven by sub thread.
- (void)droppedFromFinderSubThread:(NSPasteboard *)pboard fileDisplay:(id)fileDisplay;

// set current directory.
- (void)setCurrentDirectory:(NSString *)currentDirectory;
// reset directory view.
- (void)resetDirectoryView;
// directory selection has changed.
- (void)directorySelectionHasChanged:(id)item;
// directory selection has changed silently.
- (void)silentDirectorySelectionHasChanged:(id)item;
// rename file.
- (BOOL)renameFile:(id)item from:(NSString *)from to:(NSString *)to;
// chmod file.
- (BOOL)chmod:(id)item file:(NSString *)pathName mode:(NSString *)mode;
// rename file.
- (BOOL)renameFileTo:(NSString *)to;
// chmod file.
- (BOOL)chmodFileTo:(NSString *)mode;
// rmv file.
- (BOOL)rmvFile:(NSString *)path isDirectory:(BOOL)isDirectory;
// mkd.
- (BOOL)mkd:(NSString *)dirName;

// get current file name.
- (NSString *)currentFileName;
// get current file mode.
- (NSString *)currentFileMode;
// get file slection count.
- (NSUInteger)fileSelectionCount;
// store file.
- (BOOL)storeFile:(NSString *)filePath;
// store directory.
- (BOOL)storeDirectory:(NSString *)dirPath;
// store directory recursivelly.
- (BOOL)storeDirectoryRecursive:(NSString *)dirPath relPath:(NSString *)relPath;
// make directory if neccessary.
- (NSUInteger)makeDirectory:(NSString *)dirPath;

// is connected to server or not.
- (BOOL)isConnected;
// set file cursor position.
- (void)setFileCursorPosition:(NSUInteger)pos;
// is user choose to skip or overwrite?
- (BOOL)isSkipFile:(NSString *)path forDirectory:(BOOL)dir;
// is user choose to skip or overwrite? remote version.
- (BOOL)isSkipRemoteFile:(NSString *)path forDirectory:(BOOL)dir;
// users reply of skip or overwrite.
- (void)replaySkip:(BOOL)skip doSame:(BOOL)doSame;
// fullpath list of file display.
- (BOOL)fullpathListFileDisplay:(id)fileDisplay;
// update directory view.
- (void)updateDirectoryView;
// LIST directory.
- (id)listDir:(NSString *)dir file:(NSString *)file;
// find directory.
- (id)findDirectory:(NSString *)dir;
// store file with content.
- (BOOL)storeFile:(NSString *)filePath directory:(NSString *)dir content:(NSData *)content;
// copy directory.
- (BOOL)copyDirectory:(id)fileDisplay srcController:(id)srcController;
// recursive copy.
- (BOOL)recursiveCopyDirectory:(id)myDisplay relativePath:(NSString *)relativePath srcDisplay:(id)srcDisplay srcController:(id)srcController;
// long process strat.
- (void)longProcessStart;
// disconnected.
- (void)disconnected;
// selection double clicked.
- (void)directoryDoubleClicked:(id)fd;
// select added file.
- (void)selectAddedFiles:(NSArray *)addedFiles;
// update progress title.
- (void)updateProgressTitle:(NSString *)file directory:(NSString *)dir withFormat:(NSString *)format;
// update progress title with main thread.
- (void)mainThreadUpdateProgressTitle:(NSString *)title;
// end sub process.
- (void)endSubProcess;
// end sub process with main thread.
- (void)mainThreadEndSubProcess:(id)some;
// set can close.
- (void)setCanClose:(BOOL)canClose;
@end
